package ru.getintime.react_native_contacts_android;

import android.app.Activity;
import android.content.ContentResolver;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.provider.ContactsContract;

import com.facebook.react.bridge.ActivityEventListener;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.bridge.WritableNativeArray;

import java.util.HashMap;
import java.util.Map;

public class ReactNativeSelectContacts extends ReactContextBaseJavaModule implements ActivityEventListener {

    private Map<Integer,PickerModel> callbacks;
    private int counter;

    public ReactNativeSelectContacts(ReactApplicationContext reactContext) {
        super(reactContext);
        counter = 0;
        callbacks = new HashMap<>();
        reactContext.addActivityEventListener(this);
    }

    @ReactMethod
    public synchronized void picker(Callback callback) {
        Activity currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            callback.invoke("Activity doesn't exist");
            return;
        }
        callbacks.put(counter++,new PickerModel(callback,currentActivity));
        Intent pickIntent = new Intent(Intent.ACTION_PICK, android.provider.ContactsContract.Contacts.CONTENT_URI);
        currentActivity.startActivityForResult(pickIntent, counter-1);
    }

    @Override
    public String getName() {
        return "SelectContacts";
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        WritableMap contact = Arguments.createMap();
        contact.putInt("resultCode",resultCode);
        if(resultCode != Activity.RESULT_OK){
            callbacks.get(requestCode).getCallback().invoke(contact);
            callbacks.remove(requestCode);
            return;
        }
        Cursor cursor = callbacks.get(requestCode).getActivity().getContentResolver().query(data.getData(),null,null,null,null);
        if(cursor.moveToNext()) {
            contact.putString("id",cursor.getString(cursor.getColumnIndex(ContactsContract.Contacts._ID)));
            contact.putString("name",cursor.getString(cursor.getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME)));
            WritableArray phones = new WritableNativeArray();
            if(cursor.getString(cursor.getColumnIndex(ContactsContract.Contacts.HAS_PHONE_NUMBER)).equalsIgnoreCase("1")) {
                Cursor cursorPhones = callbacks.get(requestCode).getActivity().getContentResolver().query(
                        ContactsContract.CommonDataKinds.Phone.CONTENT_URI,
                        null,
                        ContactsContract.CommonDataKinds.Phone.CONTACT_ID + " = " + contact.getString("id"),
                        null,
                        null);
                WritableMap phone;
                while(cursorPhones.moveToNext()){
                    phone = Arguments.createMap();
                    phone.putString("id",cursorPhones.getString(cursorPhones.getColumnIndex(
                            ContactsContract.CommonDataKinds.Phone._ID)));
                    phone.putString("number",cursorPhones.getString(cursorPhones.getColumnIndex(
                            ContactsContract.CommonDataKinds.Phone.NUMBER)));
                    phones.pushMap(phone);
                }
                contact.putArray("phones", phones);
            }
        }
        callbacks.get(requestCode).getCallback().invoke(contact);
        callbacks.remove(requestCode);
    }
}
